@@ -237,5 +237,5 @@ class ChatAPI:
         return chats
 
 
-def cli_token_refresh():
+def token_refresh():
     ChatAPI().get_token()
